#!/usr/bin/python
#
'''Make Static Toppage, Sitemap and RSS.

Set server_name, proxy_destination and apache_docroot in saku.ini.
'''
#
# Copyright (c) 2006 shinGETsu Project.
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $Id: mkrss.py 1258 2006-09-04 13:21:45Z fuktommy $
#

import os.path
import sys
import socket
import urllib

import shingetsu.config
import shingetsu.mksuggest

socket.setdefaulttimeout(60)

server = shingetsu.config.server_name
destination = 'http://' + shingetsu.config.proxy_destination
docroot = shingetsu.config.apache_docroot
sep = shingetsu.config.query_separator

class AppURLopener(urllib.FancyURLopener):
    def __init__(self, *args):
        urllib.FancyURLopener.__init__(self, *args)
        self.addheader("Accept-Language", "ja;q=1.0, en;q=0.5")
urllib._urlopener = AppURLopener()

def get_rss():
    rssfile = urllib.urlopen('%s%s%srss' % (destination,
                                            shingetsu.config.gateway,
                                            sep))
    date = rssfile.info().getheader("last-modified", "")
    rss = rssfile.read()
    rssfile.close()
    return date, rss

def get_html():
    htmlfile = urllib.urlopen(destination)
    html = htmlfile.read()
    htmlfile.close()
    f = file("/srv/www/shingetsu/index.html", "w")
    f.write(html)
    f.close()

def check_date(date):
    rssdate = os.path.join(docroot, 'rssdate')
    try:
        olddate = file(rssdate).read().strip()
    except IOError:
        olddate = ""
    if date == olddate:
        sys.exit()
    else:
        file(rssdate, 'w').write(date)

def write_rss(rss):
    f = file(os.path.join(docroot, 'rss.rdf'), 'w')
    f.write(rss)
    f.close()

def get_links():
    links = ['http://%s/' % server]
    f = urllib.urlopen('%s%s%scsv/index/path' % (destination,
                                                 shingetsu.config.gateway,
                                                 sep))
    for line in f:
        links.append('http://%s'%server + line.strip())
    return links

def write_sitemap(links):
    f = file(os.path.join(docroot, 'sitemap.txt'), 'w')
    for i in links:
        f.write(i + "\n")
    f.close()

def make_suggest():
    fp = file(os.path.join(docroot, 'suggest.js'), 'w')
    titles = shingetsu.mksuggest.get_titles()
    shingetsu.mksuggest.print_jsfile(titles, fp)

def main():
    links = get_links()
    write_sitemap(links)
    date, rss = get_rss()
    check_date(date)
    write_rss(rss)
    get_html()
    make_suggest()

if __name__ == "__main__":
    main()
